@@ -39,11 +39,17 @@ typedef enum
 } SDL2_bool;
 #endif
 
+/* removed in SDL3 */
+#define SDL2_INIT_TIMER 0x00000001u
+
 /* removed in SDL3 (which only uses SDL_WINDOW_HIDDEN now). */
 #define SDL2_WINDOW_SHOWN 0x000000004
 #define SDL2_WINDOW_FULLSCREEN_DESKTOP (0x00001000 | SDL_WINDOW_FULLSCREEN)
 #define SDL2_WINDOW_SKIP_TASKBAR 0x00010000
 
+/* has a different bit set for SDL3. */
+#define SDL2_WINDOW_ALWAYS_ON_TOP 0x00008000
+
 /* removed in SDL3 (APIs like this were split into getter/setter functions). */
 #define SDL2_QUERY   -1
 #define SDL2_DISABLE  0
@@ -1205,7 +1211,6 @@ typedef struct SDL2_AudioStream
     void *callback2_buffer;
     SDL2_AudioCallback callback2;
     void *callback2_userdata;
-    SDL_AudioStream *dataqueue3;
     SDL2_bool iscapture;
 } SDL2_AudioStream;
 
