@@ -186,9 +186,9 @@ SDL2_PROTO(const char*,HapticName,(int a))
 SDL2_PROTO(SDL_Haptic*,HapticOpen,(int a))
 SDL2_PROTO(int,HapticOpened,(int a))
 SDL2_PROTO(int,HapticIndex,(SDL_Haptic *a))
-SDL2_PROTO(int,MouseIsHaptic,(void))
+SDL2_PROTO(SDL2_bool,MouseIsHaptic,(void))
 SDL2_PROTO(SDL_Haptic*,HapticOpenFromMouse,(void))
-SDL2_PROTO(int,JoystickIsHaptic,(SDL_Joystick *a))
+SDL2_PROTO(SDL2_bool,JoystickIsHaptic,(SDL_Joystick *a))
 SDL2_PROTO(SDL_Haptic*,HapticOpenFromJoystick,(SDL_Joystick *a))
 SDL2_PROTO(void,HapticClose,(SDL_Haptic *a))
 SDL2_PROTO(int,HapticNumEffects,(SDL_Haptic *a))
