@@ -490,7 +490,7 @@ SDL3_SYM_RENAMED(Uint16,JoystickGetProductVersion,GetJoystickProductVersion,(SDL
 SDL3_SYM_RENAMED(const char*,JoystickGetSerial,GetJoystickSerial,(SDL_Joystick *a),(a),return)
 SDL3_SYM_RENAMED(SDL_JoystickType,JoystickGetType,GetJoystickType,(SDL_Joystick *a),(a),return)
 SDL3_SYM_RENAMED(Uint16,JoystickGetVendor,GetJoystickVendor,(SDL_Joystick *a),(a),return)
-SDL3_SYM_RENAMED_RETCODE(bool,JoystickIsHaptic,IsJoystickHaptic,(SDL_Joystick *a),(a),return)
+SDL3_SYM_RENAMED_BOOL(bool,JoystickIsHaptic,IsJoystickHaptic,(SDL_Joystick *a),(a),return)
 SDL3_SYM_RENAMED(const char*,JoystickName,GetJoystickName,(SDL_Joystick *a),(a),return)
 SDL3_SYM_RENAMED(int,JoystickNumAxes,GetNumJoystickAxes,(SDL_Joystick *a),(a),return)
 SDL3_SYM_RENAMED(int,JoystickNumBalls,GetNumJoystickBalls,(SDL_Joystick *a),(a),return)
@@ -533,7 +533,7 @@ SDL3_SYM_PASSTHROUGH(void,Metal_DestroyView,(SDL_MetalView a),(a),)
 SDL3_SYM_PASSTHROUGH(void*,Metal_GetLayer,(SDL_MetalView a),(a),return)
 SDL3_SYM(bool,MinimizeWindow,(SDL_Window *a),(a),return)
 SDL3_SYM(bool,MixAudio,(Uint8 *a, const Uint8 *b, SDL_AudioFormat c, Uint32 d, float e),(a,b,c,d,e),return)
-SDL3_SYM_RENAMED_RETCODE(bool,MouseIsHaptic,IsMouseHaptic,(void),(),return)
+SDL3_SYM_RENAMED_BOOL(bool,MouseIsHaptic,IsMouseHaptic,(void),(),return)
 SDL3_SYM_RENAMED(void,OnApplicationDidBecomeActive,OnApplicationDidEnterForeground,(void),(),)
 SDL3_SYM_PASSTHROUGH(void,OnApplicationDidEnterBackground,(void),(),)
 SDL3_SYM_PASSTHROUGH(void,OnApplicationDidReceiveMemoryWarning,(void),(),)
@@ -612,6 +612,7 @@ SDL3_SYM(void,SetGamepadEventsEnabled,(bool a),(a),)
 SDL3_SYM(bool,SetGamepadPlayerIndex,(SDL_GameController *a, int b),(a,b),return)
 SDL3_SYM(bool,SetHint,(const char *a, const char *b),(a,b),return)
 SDL3_SYM(bool,SetHintWithPriority,(const char *a, const char *b, SDL_HintPriority c),(a,b,c),return)
+SDL3_SYM(void,SetInitialized,(SDL_InitState *a, bool b),(a,b),)
 SDL3_SYM(void,SetJoystickEventsEnabled,(bool a),(a),)
 SDL3_SYM(bool,SetJoystickPlayerIndex,(SDL_Joystick *a, int b),(a,b),return)
 SDL3_SYM(bool,SetLogPriorityPrefix,(SDL_LogPriority a, const char *b),(a,b),return)
@@ -667,12 +668,15 @@ SDL3_SYM(bool,SetWindowTitle,(SDL_Window *a, const char *b),(a,b),return)
 SDL3_SYM(bool,ShowCursor,(void),(),return)
 SDL3_SYM_PASSTHROUGH_RETCODE(bool,ShowMessageBox,(const SDL_MessageBoxData *a, int *b),(a,b),return)
 SDL3_SYM_PASSTHROUGH_RETCODE(bool,ShowSimpleMessageBox,(Uint32 a, const char *b, const char *c, SDL_Window *d),(a,b,c,d),return)
+SDL3_SYM(bool,ShouldInit,(SDL_InitState *a),(a),return)
+SDL3_SYM(bool,ShouldQuit,(SDL_InitState *a),(a),return)
 SDL3_SYM(bool,ShowWindow,(SDL_Window *a),(a),return)
 SDL3_SYM(void,SignalCondition,(SDL_Condition *a),(a),return)
 SDL3_SYM(void,SignalSemaphore,(SDL_Semaphore *a),(a),return)
 SDL3_SYM(bool,StartTextInput,(SDL_Window *a),(a),return)
 SDL3_SYM(bool,StartTextInputWithProperties,(SDL_Window *a, SDL_PropertiesID b),(a,b),return)
 SDL3_SYM(bool,StopTextInput,(SDL_Window *a),(a),return)
+SDL3_SYM(bool,StretchSurface,(SDL_Surface *a, const SDL_Rect *b, SDL_Surface *c, const SDL_Rect *d, SDL_ScaleMode e),(a,b,c,d,e),return)
 SDL3_SYM(bool,SurfaceHasColorKey,(SDL_Surface *a),(a),return)
 SDL3_SYM(bool,SurfaceHasRLE,(SDL_Surface *a),(a),return)
 SDL3_SYM_RENAMED(void,TLSCleanup,CleanupTLS,(void),(),)
@@ -704,7 +708,7 @@ SDL3_SYM(bool,WaitSemaphoreTimeout,(SDL_Semaphore *a, Sint32 b),(a,b),return)
 SDL3_SYM_PASSTHROUGH(void,WaitThread,(SDL_Thread *a, int *b),(a,b),)
 SDL3_SYM(bool,WarpMouseGlobal,(float a, float b),(a,b),return)
 SDL3_SYM(void,WarpMouseInWindow,(SDL_Window *a, float b, float c),(a,b,c),)
-SDL3_SYM_PASSTHROUGH(Uint32,WasInit,(Uint32 a),(a),return)
+SDL3_SYM(Uint32,WasInit,(Uint32 a),(a),return)
 SDL3_SYM(size_t,WriteIO,(SDL_IOStream *a, const void *b, size_t c),(a,b,c),return)
 SDL3_SYM_PASSTHROUGH(int,abs,(int a),(a),return)
 SDL3_SYM_PASSTHROUGH(double,acos,(double a),(a),return)
